==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/ActivityItem/ActivityItem.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent.js';
import '../node_modules/core-js/modules/es.symbol.js';
import '../node_modules/core-js/modules/es.array.filter.js';
import '../node_modules/core-js/modules/es.array.for-each.js';
import '../node_modules/core-js/modules/es.object.define-properties.js';
import '../node_modules/core-js/modules/es.object.define-property.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../node_modules/core-js/modules/es.object.keys.js';
import '../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import '../node_modules/core-js/modules/es.array.map.js';
import { getStyles } from './ActivityItem.styles.js';
import { getClassNames } from './ActivityItem.classNames.js';
import { PersonaSize } from '../Persona/Persona.types.js';
import { PersonaCoin } from '../Persona/PersonaCoin/index.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var ActivityItem = function (_BaseComponent) {
  _inherits(ActivityItem, _BaseComponent);

  var _super = _createSuper(ActivityItem);

  function ActivityItem() {
    var _this;

    _classCallCheck(this, ActivityItem);

    _this = _super.apply(this, arguments);
    _this.PersonaSize = PersonaSize;
    return _this;
  }

  _createClass(ActivityItem, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          activityPersonas = this.activityPersonas,
          animateBeaconSignal = this.animateBeaconSignal,
          isCompact = this.isCompact,
          personasToRender = this.personasToRender,
          personaStyle = this.personaStyle;
      return h("div", {
        "class": classNames.root
      }, [(activityPersonas || this.$slots.icon) && h("div", {
        "class": classNames.activityTypeIcon
      }, [animateBeaconSignal && isCompact && h("div", {
        "class": classNames.pulsingBeacon
      }), activityPersonas.length > 0 && h("div", {
        "class": classNames.personaContainer
      }, [personasToRender.map(function (person, index) {
        return h(PersonaCoin, {
          "props": _objectSpread({}, person),
          "key": person.key || index,
          "class": classNames.activityPersona,
          "attrs": {
            "size": activityPersonas.length > 1 || isCompact ? PersonaSize.size16 : PersonaSize.size32
          },
          "style": personaStyle
        });
      })]), this.$slots.icon]), h("div", {
        "class": classNames.activityContent
      }, [this.$slots.activityDescription && h("span", {
        "class": classNames.activityText
      }, [this.$slots.activityDescription]), !isCompact && this.$slots.comments && h("div", {
        "class": classNames.commentText
      }, [this.$slots.comments]), !isCompact && this.$slots.timeStamp && h("div", {
        "class": classNames.timeStamp
      }, [this.$slots.timeStamp])])]);
    }
  }, {
    key: "personaStyle",
    get: function get() {
      if (!this.isCompact) return {};
      return {
        display: 'inline-block',
        width: '10px',
        minWidth: '10px',
        overflow: 'visible'
      };
    }
  }, {
    key: "personasToRender",
    get: function get() {
      var personaLimit = this.isCompact ? 3 : 4;
      return this.activityPersonas.filter(function (person, index) {
        return index < personaLimit;
      });
    }
  }, {
    key: "classNames",
    get: function get() {
      var styles = this.styles,
          theme = this.theme,
          className = this.className,
          activityPersonas = this.activityPersonas,
          animateBeaconSignal = this.animateBeaconSignal,
          beaconColorOne = this.beaconColorOne,
          beaconColorTwo = this.beaconColorTwo,
          isCompact = this.isCompact;
      return getClassNames(getStyles(theme, styles, animateBeaconSignal, beaconColorOne, beaconColorTwo, isCompact), className, activityPersonas, isCompact);
    }
  }]);

  return ActivityItem;
}(BaseComponent);

__decorate([Prop({
  type: Array,
  "default": function _default() {
    return [];
  }
}), __metadata("design:type", Array)], ActivityItem.prototype, "activityPersonas", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], ActivityItem.prototype, "animateBeaconSignal", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], ActivityItem.prototype, "beaconColorOne", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], ActivityItem.prototype, "beaconColorTwo", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], ActivityItem.prototype, "isCompact", void 0);

ActivityItem = __decorate([Component({
  components: {
    PersonaCoin: PersonaCoin
  }
})], ActivityItem);

export { ActivityItem };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/ActivityItem/ActivityItem.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent.js';
import 'core-js/modules/es.symbol';
import 'core-js/modules/es.array.filter';
import 'core-js/modules/es.array.for-each';
import 'core-js/modules/es.object.get-own-property-descriptor';
import 'core-js/modules/es.object.get-own-property-descriptors';
import 'core-js/modules/es.object.keys';
import 'core-js/modules/web.dom-collections.for-each';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import 'core-js/modules/es.array.map';
import { getStyles } from './ActivityItem.styles.js';
import { getClassNames } from './ActivityItem.classNames.js';
import { PersonaSize } from '../Persona/Persona.types.js';
import { PersonaCoin } from '../Persona/PersonaCoin/index.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var ActivityItem = function (_BaseComponent) {
  _inherits(ActivityItem, _BaseComponent);

  var _super = _createSuper(ActivityItem);

  function ActivityItem() {
    var _this;

    _classCallCheck(this, ActivityItem);

    _this = _super.apply(this, arguments);
    _this.PersonaSize = PersonaSize;
    return _this;
  }

  _createClass(ActivityItem, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          activityPersonas = this.activityPersonas,
          animateBeaconSignal = this.animateBeaconSignal,
          isCompact = this.isCompact,
          personasToRender = this.personasToRender,
          personaStyle = this.personaStyle;
      return h("div", {
        "class": classNames.root
      }, [(activityPersonas || this.$slots.icon) && h("div", {
        "class": classNames.activityTypeIcon
      }, [animateBeaconSignal && isCompact && h("div", {
        "class": classNames.pulsingBeacon
      }), activityPersonas.length > 0 && h("div", {
        "class": classNames.personaContainer
      }, [personasToRender.map(function (person, index) {
        return h(PersonaCoin, {
          "props": _objectSpread({}, person),
          "key": person.key || index,
          "class": classNames.activityPersona,
          "attrs": {
            "size": activityPersonas.length > 1 || isCompact ? PersonaSize.size16 : PersonaSize.size32
          },
          "style": personaStyle
        });
      })]), this.$slots.icon]), h("div", {
        "class": classNames.activityContent
      }, [this.$slots.activityDescription && h("span", {
        "class": classNames.activityText
      }, [this.$slots.activityDescription]), !isCompact && this.$slots.comments && h("div", {
        "class": classNames.commentText
      }, [this.$slots.comments]), !isCompact && this.$slots.timeStamp && h("div", {
        "class": classNames.timeStamp
      }, [this.$slots.timeStamp])])]);
    }
  }, {
    key: "personaStyle",
    get: function get() {
      if (!this.isCompact) return {};
      return {
        display: 'inline-block',
        width: '10px',
        minWidth: '10px',
        overflow: 'visible'
      };
    }
  }, {
    key: "personasToRender",
    get: function get() {
      var personaLimit = this.isCompact ? 3 : 4;
      return this.activityPersonas.filter(function (person, index) {
        return index < personaLimit;
      });
    }
  }, {
    key: "classNames",
    get: function get() {
      var styles = this.styles,
          theme = this.theme,
          className = this.className,
          activityPersonas = this.activityPersonas,
          animateBeaconSignal = this.animateBeaconSignal,
          beaconColorOne = this.beaconColorOne,
          beaconColorTwo = this.beaconColorTwo,
          isCompact = this.isCompact;
      return getClassNames(getStyles(theme, styles, animateBeaconSignal, beaconColorOne, beaconColorTwo, isCompact), className, activityPersonas, isCompact);
    }
  }]);

  return ActivityItem;
}(BaseComponent);

__decorate([Prop({
  type: Array,
  default: function _default() {
    return [];
  }
}), __metadata("design:type", Array)], ActivityItem.prototype, "activityPersonas", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ActivityItem.prototype, "animateBeaconSignal", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], ActivityItem.prototype, "beaconColorOne", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], ActivityItem.prototype, "beaconColorTwo", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ActivityItem.prototype, "isCompact", void 0);

ActivityItem = __decorate([Component({
  components: {
    PersonaCoin: PersonaCoin
  }
})], ActivityItem);

export { ActivityItem };
